@@ -8,7 +8,7 @@ use Log::Any '$log';
 use Path::Naive qw(is_abs_path normalize_path concat_path_n);
 #use Perinci::Sub::Util qw(err);
 
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 our $DATE = '2014-08-06'; # DATE
 
 # like Path::Naive's concat_path_n, but adds "/" at the end when it thinks the
@@ -275,8 +275,7 @@ $SPEC{set} = {
 
                 my %args = @_;
                 my $shell = $args{extras}{-shell};
-
-                my $args = $args{args};
+                my $args  = $args{extras}{args};
                 return [] unless $args->{name};
                 my $setting = $shell->known_settings->{ $args->{name} };
                 return [] unless $setting;
@@ -555,7 +554,7 @@ App::riap::Commands - riap shell commands
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =for Pod::Coverage .+
 
